@@ -211,11 +211,12 @@ class FileLoader {
 	 * @param Array $files The files to print
 	 * @param String $template The template used to print each file, the string {file} will
 	 * be replaced with the filename 
+	 * @param Boolean $base True if only the basename of the file must be printed
 	 */
-	public function printFiles($files, $template = '{file}')
+	public function printFiles($files, $template = '{file}', $base = false)
 	{
 		foreach($files as $file) {
-			echo str_replace('{file}', $file, $template) . PHP_EOL;
+			echo str_replace('{file}', $base === true ? basename($file) : $file, $template) . PHP_EOL;
 		}
 	}
 
