@@ -11,7 +11,7 @@ $version = trim(file_get_contents('version'));
 ?>
 <!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
 <html>
-	
+
 	<head>
 		<meta name="Generator" content="Zarafa WebApp v<?=$version?>">
 		<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
@@ -44,7 +44,7 @@ $version = trim(file_get_contents('version'));
 		<script type="text/javascript" src="index.php?version=<?=$version?>&amp;load=translations.js&amp;lang=<?=$GLOBALS["language"]->getSelected()?>"></script>
 
 		<!-- ExtJS & Thirdparty extensions-->
-		<?php	
+		<?php
 			$extjsFiles = $loader->getExtjsJavascriptFiles(DEBUG_LOADER);
 			$loader->printFiles($extjsFiles, $jsTemplate);
 		?>
@@ -60,7 +60,7 @@ $version = trim(file_get_contents('version'));
 			$remoteFiles = $loader->getRemoteJavascriptFiles(DEBUG_LOADER);
 			$loader->printFiles($remoteFiles, $jsTemplate);
 		?>
-		
+
 		<script type="text/javascript">
 			settings = <?= JSON::Encode($GLOBALS["settings"]->getJSON()); ?>;
 		</script>
@@ -101,6 +101,21 @@ $version = trim(file_get_contents('version'));
 			};
 		</script>
 
+		<!-- get URL data from session and dump it for client to use -->
+		<?php
+			$urlActionData = array();
+			if(!empty($_SESSION['url_action'])) {
+				$urlActionData = $_SESSION['url_action'];
+
+				// remove data from session so if user reloads webapp then we will again not execute url action
+				unset($_SESSION['url_action']);
+			}
+		?>
+
+		<script type="text/javascript">
+			urlActionData = <?= JSON::Encode($urlActionData); ?>;
+		</script>
+
 		<script type="text/javascript">
 			Ext.onReady(Zarafa.loadWebclient, Zarafa);
 		</script>
