@@ -1,7 +1,7 @@
 <?php
 	/**
 	 * This is the entry point for every request that should return HTML
-	 * 
+	 *
 	 * (one exception is that it also returns translated text for javascript)
 	 */
 	// load config file
@@ -50,7 +50,7 @@
 	require("server/core/class.conversion.php");
 	require("server/core/class.mapisession.php");
 	require("server/core/class.entryid.php");
-	
+
 	require("server/core/class.settings.php");
 	require("server/core/class.language.php");
 
@@ -60,17 +60,18 @@
 	require("server/core/class.pluginmanager.php");
 	require("server/core/class.plugin.php");
 
-	// Determine the action, use 'null' as default value
-	// so we will recognize arguments without value properly.
-	$logout = sanitizeGetValue('logout', null, STRING_REGEX) !== null;
-	$logon = sanitizeGetValue('logon', null, STRING_REGEX) !== null;
+	// Check if we need to logout from webapp
+	$logout = isset($_GET['logout']);
+	// Check if we have been redirected from login page
+	$logon = isset($_GET['logon']);
+	// Check for loading of any other type of file
 	$load = sanitizeGetValue('load', false, FILENAME_REGEX);
 
 	// Returns true if the given $load argument
 	// requires a validated session.
 	function loadNeedsSession($load)
 	{
-		return !empty($load) && $load !== 'logon' && $load !== 'translations.js'; 
+		return !empty($load) && $load !== 'logon' && $load !== 'translations.js';
 	}
 
 	// Destroy session
@@ -92,7 +93,7 @@
 
 		destroySession();
 
-		$user = sanitizeGetValue('user', false, USERNAME_REGEX);
+		$user = sanitizeGetValue('user', '', USERNAME_REGEX);
 		if ($user) {
 			$actionURI .= '&user=' . rawurlencode($user);
 		}
@@ -118,19 +119,32 @@
 			$_SESSION['password'] = $password;
 		}
 
-       } else if (!DISABLE_REMOTE_USER_LOGIN && !isset($_SESSION['username'])) {
-               // REMOTE_USER is set when apache has authenticated the user
-               // Don't perform single-signon when $_POST is set, as that implies
-               // the user was sending us data from a form.
-               if (!$_POST && $_SERVER && array_key_exists('REMOTE_USER', $_SERVER)) {
-                       $_SESSION['username'] = $_SERVER['REMOTE_USER'];
-                       if (LOGINNAME_STRIP_DOMAIN) {
-                               $_SESSION['username'] = ereg_replace('@.*', '', $_SESSION['username']);
-                       }   
-                       $_SESSION['password'] = '';
+	} else if (!DISABLE_REMOTE_USER_LOGIN && !isset($_SESSION['username'])) {
+		// REMOTE_USER is set when apache has authenticated the user
+		// Don't perform single-signon when $_POST is set, as that implies
+		// the user was sending us data from a form.
+		if (!$_POST && $_SERVER && array_key_exists('REMOTE_USER', $_SERVER)) {
+			$_SESSION['username'] = $_SERVER['REMOTE_USER'];
+			if (LOGINNAME_STRIP_DOMAIN) {
+				$_SESSION['username'] = ereg_replace('@.*', '', $_SESSION['username']);
+			}
+
+			$_SESSION['password'] = '';
 		}
 	}
 
+	$urlAction = sanitizeGetValue('action', '', STRING_REGEX);
+	if(!empty($urlAction)) {
+		// get data from url and store it in session, which can be maintained across lots of redirects
+		// between login.php and welcome.php and webclient.php
+		storeURLDataToSession();
+
+		// after storing data in session we can refresh the page to remove url data
+		// and restore normal url for webapp
+		header('Location: index.php', true, 303);
+		exit;
+	}
+
 	// Create global mapi object. This object is used in many other files
 	$GLOBALS["mapisession"] = new MAPISession(session_id());
 
@@ -138,7 +152,7 @@
 	// sessionid as send in the cookie. Otherwise the cookie was somehow modified in the
 	// browser.
 	$sessionid = sanitizeGetValue('sessionid', '', ID_REGEX);
-	if (loadNeedsSession($load) && $sessionid !== $GLOBALS["mapisession"]->getSessionId()) {
+	if (loadNeedsSession($load) && $sessionid !== $GLOBALS["mapisession"]->getSessionID()) {
 		$hresult = MAPI_E_INVALID_WORKSTATION_ACCOUNT;
 	} else if ($load !== 'logon' && isset($_SESSION["username"]) && isset($_SESSION["password"])) {
 		$sslcert_file = defined('SSLCERT_FILE') ? SSLCERT_FILE : null;
@@ -154,10 +168,19 @@
 		$GLOBALS['PluginManager'] = new PluginManager(ENABLE_PLUGINS);
 		$GLOBALS['PluginManager']->detectPlugins(DISABLED_PLUGINS_LIST);
 		$GLOBALS['PluginManager']->initPlugins(DEBUG_LOADER);
-		
+
+		if ($logon) {
+			// we are coming here from login page, redirect again so we will remove $_POST data
+			// otherwise when user tries to reload webapp, browser will ask to again send request which is invalid
+			$GLOBALS['PluginManager']->triggerHook("server.index.login.success");
+
+			header('Location: index.php', true, 303);
+			exit;
+		}
+
 		// Create globals settings object
 		$GLOBALS["settings"] = new Settings();
-		
+
 		// Create global language object
 		$GLOBALS["language"] = new Language();
 
@@ -165,7 +188,7 @@
 		foreach($GLOBALS["settings"]->getSessionSettings() as $key=>$value){
 			$_SESSION[$key] = $value;
 		}
-		
+
 		// Get settings from post or session or settings
 		if (isset($_REQUEST["language"]) && $GLOBALS["language"]->is_language($_REQUEST["language"])) {
 			$lang = $_REQUEST["language"];
@@ -182,11 +205,6 @@
 		}
 
 		$GLOBALS["language"]->setLanguage($lang);
-		if ($logon) {
-			$GLOBALS['PluginManager']->triggerHook("server.index.login.success");
-			header("Location: index.php", true, 303);
-			exit;
-		}
 
 		// add extra header
 		header("X-Zarafa: " . trim(file_get_contents('version')));
@@ -260,14 +278,14 @@
 			);
 			echo JSON::Encode(array("zarafa" => $data));
 		} else if ($_GET && array_key_exists("verify", $_GET)) {
-			
-			$user = sanitizeGetValue('verify', false, USERNAME_REGEX);
-			
+
+			$user = sanitizeGetValue('verify', '', USERNAME_REGEX);
+
 			if($user == $_SESSION['username'])
 				print "1";
 			else
 				print "0";
-			
+
 		} else if (!DISABLE_WELCOME_SCREEN && $GLOBALS["settings"]->get("zarafa/v1/main/show_welcome") !== false) {
 			// The user wants to logon, but he never did this before (or was using
 			// an older version of WebApp, before the Welcome screen was introduced),
@@ -280,8 +298,8 @@
 			include("client/welcome.php");
 			$GLOBALS['PluginManager']->triggerHook("server.index.load.welcome.after");
 		} else {
-			// Set the show_welcome to true, so that when the admin is changing the 
-			// DISABLE_WELCOME_SCREEN option to false after some time, the users who are already 
+			// Set the show_welcome to true, so that when the admin is changing the
+			// DISABLE_WELCOME_SCREEN option to false after some time, the users who are already
 			// using the WebApp are not bothered with the Welcome Screen.
 			$GLOBALS["settings"]->set("zarafa/v1/main/show_welcome", false);
 
