@@ -1185,4 +1185,9 @@ define('PR_ZC_CONTACT_STORE_ENTRYIDS'         ,mapi_prop_tag(PT_MV_BINARY, PR_EC
 define('PR_ZC_CONTACT_FOLDER_ENTRYIDS'        ,mapi_prop_tag(PT_MV_BINARY, PR_EC_BASE+0x12));
 define('PR_ZC_CONTACT_FOLDER_NAMES'           ,mapi_prop_tag(PT_MV_TSTRING, PR_EC_BASE+0x13));
 
+/* zarafa specific properties for optimization of imap functionality */
+define('PR_EC_IMAP_EMAIL'                     ,mapi_prop_tag(PT_BINARY,  PR_EC_BASE+0x8C)); //the complete rfc822 email
+define('PR_EC_IMAP_EMAIL_SIZE'                ,mapi_prop_tag(PT_LONG,    PR_EC_BASE+0x8D));
+define('PR_EC_IMAP_BODY'                      ,mapi_prop_tag(PT_STRING8, PR_EC_BASE+0x8E)); //simplified bodystructure (mostly unused by clients)
+define('PR_EC_IMAP_BODYSTRUCTURE'             ,mapi_prop_tag(PT_STRING8, PR_EC_BASE+0x8F)); //extended bodystructure (often used by clients)
 ?>
