@@ -1,6 +1,7 @@
 <?php
 // Include backwards compatibility
 require_once("server/sys_get_temp_dir.php");
+require_once("server/util.php");
 
 //unique id for attachment
 $tmpname = tempnam(sys_get_temp_dir(), md5(uniqid(rand(),true)));
@@ -9,5 +10,5 @@ $tmpname = tempnam(sys_get_temp_dir(), md5(uniqid(rand(),true)));
 move_uploaded_file($_FILES["file"]["tmp_name"], $tmpname);
 
 //returns query string to script file
-echo "&attachment_id=".basename($tmpname)."&name=".$_FILES["file"]["name"];
+echo "&attachment_id=".mb_basename($tmpname)."&name=".$_FILES["file"]["name"];
 ?>
