@@ -4,7 +4,7 @@
 	 * MAPI session handling
 	 *
 	 * This class handles MAPI authentication and stores
-	 * 
+	 *
 	 * @package core
 	 */
 	class MAPISession
@@ -44,23 +44,23 @@
 		 * @var array Information about the current session (username/email/password/etc)
 		 */
 		var $session_info;
-		
+
 		/**
 		 * @var array Mapping username -> entryid for other stores
 		 */
-		 
+
 		var $userstores;
-		 
-		 
+
+
 		/**
 		 * @var int Makes sure retrieveUserData is called only once
 		 */
 		var $userDataRetrieved;
-		
+
 		/**
 		 * Default constructor
 		 * @param String The sessionid for which this MAPI Session is created
-		 */		 		
+		 */
 		function MAPISession($sessionid)
 		{
 			$this->sessionid = $sessionid;
@@ -72,8 +72,8 @@
 			$this->ab = false;
 			$this->userstores = array();
 			$this->userDataRetrieved = false;
-		} 
-	
+		}
+
 		/**
 		 * Logon to Zarafa's MAPI system via php MAPI extension
 		 *
@@ -81,12 +81,12 @@
 		 * it will logon to the local server.
 		 *
 		 * @param string $username the username of the user
-		 * @param string $password the password of the user 
+		 * @param string $password the password of the user
 		 * @param string $server the server address
 		 * @param string $sslcert_file the optional ssl certificate file
 		 * @param string $sslcert_pass the optional ssl certificate password
 		 * @result int 0 on no error, otherwise a MAPI error code
-		 */		 		
+		 */
 		function logon($username = NULL, $password = NULL, $server = DEFAULT_SERVER, $sslcert_file = NULL, $sslcert_pass = NULL)
 		{
 			$result = NOERROR;
@@ -101,7 +101,7 @@
 					$this->session_info["username"] = $username;
 					$this->session_info["password"] = $password;
 					$this->session_info["server"] = $server;
-					
+
 					// we are authenticated
 					$this->session_info["auth"] = true;
 				}
@@ -130,7 +130,7 @@
 		{
 			if($this->userDataRetrieved)
 				return;
-				
+
 			$result = NOERROR;
 
 			try {
@@ -173,7 +173,7 @@
 		/**
 		 * Get MAPI addressbook object
 		 *
-		 * @param string $fresh (optional) When set to true it will return an addressbook resource 
+		 * @param string $fresh (optional) When set to true it will return an addressbook resource
 		 * without any Contact Provider set on it, defaults to false.
 		 * @return mapiaddressbook An addressbook object to be used with mapi_ab_*
 		 */
@@ -197,7 +197,7 @@
 				if ($this->ab === false){
 					$this->ab = mapi_openaddressbook($this->session);
 				}
-				
+
 				if ($this->ab !== false){
 					$result = $this->ab;
 				}
@@ -213,7 +213,7 @@
 		 * Get logon status
 		 *
 		 * @return boolean true on logged on, false on not logged on
-		 */		 		
+		 */
 		function isLoggedOn()
 		{
 			return array_key_exists("auth",$this->session_info)?$this->session_info["auth"]:false;
@@ -234,8 +234,8 @@
 		 */
 		function getUserEntryID()
 		{
-			$result = $this->retrieveUserData(); 
-			
+			$result = $this->retrieveUserData();
+
 			return array_key_exists("userentryid",$this->session_info)?$this->session_info["userentryid"]:false;
 		}
 
@@ -245,8 +245,8 @@
 		 */
 		function getUserName()
 		{
-			$result = $this->retrieveUserData(); 
-			
+			$result = $this->retrieveUserData();
+
 			return array_key_exists("username",$this->session_info)?$this->session_info["username"]:false;
 		}
 
@@ -256,8 +256,8 @@
 		 */
 		function getFullName()
 		{
-			$result = $this->retrieveUserData(); 
-			
+			$result = $this->retrieveUserData();
+
 			return array_key_exists("fullname",$this->session_info)?$this->session_info["fullname"]:false;
 		}
 
@@ -267,8 +267,8 @@
 		 */
 		function getSMTPAddress()
 		{
-			$result = $this->retrieveUserData(); 
-			
+			$result = $this->retrieveUserData();
+
 			return array_key_exists("smtpaddress",$this->session_info)?$this->session_info["smtpaddress"]:false;
 		}
 
@@ -278,8 +278,8 @@
 		 */
 		function getEmailAddress()
 		{
-			$result = $this->retrieveUserData(); 
-			
+			$result = $this->retrieveUserData();
+
 			return array_key_exists("emailaddress",$this->session_info)?$this->session_info["emailaddress"]:false;
 		}
 
@@ -295,8 +295,8 @@
 		}
 
 		/**
-		 * Get the message stores from the messge store table from your session. Standard stores 
-		 * like the default store and the public store are made them easily accessible through the 
+		 * Get the message stores from the messge store table from your session. Standard stores
+		 * like the default store and the public store are made them easily accessible through the
 		 * defaultstore and publicStore properties.
 		 */
 		function loadMessageStoresFromSession()
@@ -352,7 +352,7 @@
 				return false;
 			}
 		}
-	
+
 		/**
 		 * Get all message stores currently open in the session
 		 *
@@ -419,7 +419,7 @@
 
 			return $store;
 		}
-	
+
 		/**
 		 * Resolve a username to its entryid
 		 *
@@ -491,11 +491,11 @@
 
 			if($user_entryid) {
 				$this->userstores[$username] = $user_entryid;
-			
+
 				return $this->openMessageStore($user_entryid);
 			}
 		}
-		
+
 		/**
 		 * Remove the store of another user from the list of other user stores
 		 *
@@ -511,7 +511,7 @@
 				unset($this->stores[$entryid]);
 				return $entryid;
 			}
-		}	
+		}
 
 		/**
 		 * Get the store entryid of the specified user
@@ -540,7 +540,7 @@
 				if($GLOBALS["entryid"]->compareStoreEntryIds(bin2hex($storeentryid), bin2hex($entryid)))
 					return $username;
 			}
-			
+
 			return false;
 		}
 
@@ -554,11 +554,11 @@
 		 */
 		function openMessage($entryid)
 		{
-			return mapi_openentry($this->session, $entryid); 
+			return mapi_openentry($this->session, $entryid);
 		}
 
 		/**
-		 * Setup the contact provider for the addressbook. It asks getContactFoldersForABContactProvider 
+		 * Setup the contact provider for the addressbook. It asks getContactFoldersForABContactProvider
 		 * for the entryids and display names for the contact folders in the user's store.
 		 */
 		function setupContactProviderAddressbook()
@@ -569,7 +569,11 @@
 				$defaultStore = $this->getDefaultMessageStore();
 				$contactFolders = $this->getContactFoldersForABContactProvider($defaultStore);
 				$publicStore = $this->getPublicMessageStore();
-				$contactFolders = array_merge($contactFolders, $this->getContactFoldersForABContactProvider($publicStore));
+
+				// get contact folders from public store if public store exists
+				if($publicStore !== false) {
+					$contactFolders = array_merge($contactFolders, $this->getContactFoldersForABContactProvider($publicStore));
+				}
 				//TODO: The shared stores are not opened as there still is a bug that does not allow resolving from shared contact folders
 
 				// These lists will be used to put set in the profile section
@@ -577,7 +581,7 @@
 				$contact_folder_entryids = Array();
 				$contact_folder_names = Array();
 
-				// Create the lists of store entryids, folder entryids and folder names to be added 
+				// Create the lists of store entryids, folder entryids and folder names to be added
 				// to the profile section
 				for($i=0,$len=count($contactFolders);$i<$len;$i++){
 					$contact_store_entryids[] = $contactFolders[$i][PR_STORE_ENTRYID];
@@ -595,8 +599,8 @@
 		}
 
 		/**
-		 * Get the store entryid, folder entryid and display name of the contact folders in the 
-		 * user's store. It returns an array where each item contains the information of one folder 
+		 * Get the store entryid, folder entryid and display name of the contact folders in the
+		 * user's store. It returns an array where each item contains the information of one folder
 		 * formatted like this:
 		 * Array(
 		 *     PR_STORE_ENTRYID => '1234567890ABCDEF',
@@ -609,7 +613,8 @@
 		function getContactFoldersForABContactProvider($store)
 		{
 			$storeProps = mapi_getprops($store, array(PR_ENTRYID, PR_MDB_PROVIDER, PR_IPM_SUBTREE_ENTRYID, PR_IPM_PUBLIC_FOLDERS_ENTRYID));
-			// For the public store we need to use the PR_IPM_PUBLIC_FOLDERS_ENTRYID instead of the 
+
+			// For the public store we need to use the PR_IPM_PUBLIC_FOLDERS_ENTRYID instead of the
 			// PR_IPM_SUBTREE_ENTRYID that can be used on your own and delegate stores.
 			if($storeProps[PR_MDB_PROVIDER] == ZARAFA_STORE_PUBLIC_GUID){
 				$subtreeEntryid = $storeProps[PR_IPM_PUBLIC_FOLDERS_ENTRYID];
@@ -623,7 +628,7 @@
 
 			$restriction = array(RES_CONTENT,
 				array(
-					// Fuzzylevel PF_PREFIX also allows IPF.Contact.Custom folders to be included. 
+					// Fuzzylevel PF_PREFIX also allows IPF.Contact.Custom folders to be included.
 					// Otherwise FL_FULLSTRING would only allow IPF.Contact folders.
 					FUZZYLEVEL => FL_PREFIX,
 					ULPROPTAG => PR_CONTAINER_CLASS,
