@@ -38,7 +38,7 @@ class PluginManager
 	var $pluginorder;
 
 	/**
-	 * List of all hooks registered by plugins. 
+	 * List of all hooks registered by plugins.
 	 * [eventID][] = plugin
 	 */
 	var $hooks;
@@ -62,7 +62,7 @@ class PluginManager
 	var $notifiers;
 
 	/**
-	 * List of sessiondata from plugins. 
+	 * List of sessiondata from plugins.
 	 * [pluginname] = sessiondata
 	 */
 	var $sessionData;
@@ -116,23 +116,23 @@ class PluginManager
 			$this->pluginpath = PATH_PLUGIN_DIR;
 			$this->pluginconfigpath = PATH_PLUGIN_CONFIG_DIR;
 		}
-	} 
+	}
 
 	/**
 	 * pluginsEnabled
-	 * 
-	 * Checks whether the plugins have been enabled by checking if the proper 
+	 *
+	 * Checks whether the plugins have been enabled by checking if the proper
 	 * configuration keys are set.
 	 * @return boolean Returns true when plugins enabled, false when not.
 	 */
 	function pluginsEnabled(){
 		return $this->enabled;
 	}
-	
+
 	/**
 	 * detectPlugins
-	 * 
-	 * Detecting the installed plugins either by using the already ready data 
+	 *
+	 * Detecting the installed plugins either by using the already ready data
 	 * from the state object or otherwise read in all the data and write it into
 	 * the state.
 	 *
@@ -360,12 +360,12 @@ class PluginManager
 
 	/**
 	 * initPlugins
-	 * 
-	 * This function includes the server plugin classes, instantiate and 
+	 *
+	 * This function includes the server plugin classes, instantiate and
 	 * initialize them.
-	 * 
+	 *
 	 * @param number $load One of LOAD_RELEASE, LOAD_DEBUG, LOAD_SOURCE. This will filter
-	 * the files based on the 'load' attribute. 
+	 * the files based on the 'load' attribute.
 	 */
 	function initPlugins($load = LOAD_RELEASE){
 		if(!$this->pluginsEnabled()){
@@ -394,10 +394,10 @@ class PluginManager
 
 	/**
 	 * processPlugin
-	 * 
-	 * Read in the manifest and get the files that need to be included 
-	 * for placing hooks, defining modules, etc. 
-	 * 
+	 *
+	 * Read in the manifest and get the files that need to be included
+	 * for placing hooks, defining modules, etc.
+	 *
 	 * @param $dirname string name of the directory of the plugin
 	 * @return array The plugin data read from the given directory
 	 */
@@ -406,7 +406,7 @@ class PluginManager
 		$handle = fopen($this->pluginpath . DIRECTORY_SEPARATOR . $dirname . DIRECTORY_SEPARATOR . 'manifest.xml', 'rb');
 		$xml = '';
 		if($handle){
-			while (!feof($handle)) { 
+			while (!feof($handle)) {
 				$xml .= fread($handle, 4096);
 			}
 			fclose($handle);
@@ -426,11 +426,11 @@ class PluginManager
 
 	/**
 	 * loadSessionData
-	 * 
-	 * Loads sessiondata of the plugins from disk. 
-	 * To improve performance the data is only loaded if a 
+	 *
+	 * Loads sessiondata of the plugins from disk.
+	 * To improve performance the data is only loaded if a
 	 * plugin requests (reads or saves) the data.
-	 * 
+	 *
 	 * @param $pluginname string Identifier of the plugin
 	 */
 	function loadSessionData($pluginname) {
@@ -453,11 +453,11 @@ class PluginManager
 
 	/**
 	 * saveSessionData
-	 * 
-	 * Saves sessiondata of the plugins to the disk. 
-	 * 
+	 *
+	 * Saves sessiondata of the plugins to the disk.
+	 *
 	 * @param $pluginname string Identifier of the plugin
-	 */	
+	 */
 	function saveSessionData($pluginname) {
 		if ($this->pluginExists($pluginname)) {
 			$this->sessionData[$pluginname] = $this->plugins[ $pluginname ]->getSessionData();
@@ -469,12 +469,12 @@ class PluginManager
 			$sessState->close();
 		}
 	}
-	
+
 	/**
 	 * pluginExists
-	 * 
+	 *
 	 * Checks if plugin exists.
-	 * 
+	 *
 	 * @param $pluginname string Identifier of the plugin
 	 * @return boolen True when plugin exists, false when it does not.
 	 */
@@ -522,9 +522,9 @@ class PluginManager
 
 	/**
 	 * registerHook
-	 * 
+	 *
 	 * This function allows the plugin to register their hooks.
-	 * 
+	 *
 	 * @param $eventID string Identifier of the event where this hook must be triggered.
 	 * @param $pluginName string Name of the plugin that is registering this hook.
 	 */
@@ -534,9 +534,9 @@ class PluginManager
 
 	/**
 	 * triggerHook
-	 * 
+	 *
 	 * This function will call all the registered hooks when their event is triggered.
-	 * 
+	 *
 	 * @param $eventID string Identifier of the event that has just been triggered.
 	 * @param $data mixed (Optional) Usually an array of data that the callback function can modify.
 	 * @return mixed Data that has been changed by plugins.
@@ -566,7 +566,7 @@ class PluginManager
 	 * @param String $pluginname The name of the plugin (this is used in the pathname)
 	 * @param Array $component The component to read the serverfiles from
 	 * @param number $load One of LOAD_RELEASE, LOAD_DEBUG, LOAD_SOURCE. This will filter
-	 * the files based on the 'load' attribute. 
+	 * the files based on the 'load' attribute.
 	 * @return array list of paths to the files in this component
 	 */
 	function getServerFilesForComponent($pluginname, $component, $load)
@@ -603,7 +603,7 @@ class PluginManager
 
 	/**
 	 * getServerFiles
-	 * 
+	 *
 	 * Returning an array of paths to files that need to be included.
 	 * The paths which are returned start at the root of the webapp.
 	 *
@@ -612,7 +612,7 @@ class PluginManager
 	 *
 	 * @param string $pluginname The name of the plugin for which the server files are requested.
 	 * @param number $load One of LOAD_RELEASE, LOAD_DEBUG, LOAD_SOURCE. This will filter
-	 * the files based on the 'load' attribute. 
+	 * the files based on the 'load' attribute.
 	 * @return array List of paths to files.
 	 */
 	function getServerFiles($load = LOAD_RELEASE)
@@ -663,7 +663,7 @@ class PluginManager
 	 * @param String $pluginname The name of the plugin (this is used in the pathname)
 	 * @param Array $component The component to read the clientfiles from
 	 * @param number $load One of LOAD_RELEASE, LOAD_DEBUG, LOAD_SOURCE. This will filter
-	 * the files based on the 'load' attribute. 
+	 * the files based on the 'load' attribute.
 	 * @return array list of paths to the files in this component
 	 */
 	function getClientFilesForComponent($pluginname, $component, $load)
@@ -680,7 +680,7 @@ class PluginManager
 
 	/**
 	 * getClientFiles
-	 * 
+	 *
 	 * Returning an array of paths to files that need to be included.
 	 * The paths which are returned start at the root of the webapp.
 	 *
@@ -688,7 +688,7 @@ class PluginManager
 	 * for each component inside each plugin.
 	 *
 	 * @param number $load One of LOAD_RELEASE, LOAD_DEBUG, LOAD_SOURCE. This will filter
-	 * the files based on the 'load' attribute. 
+	 * the files based on the 'load' attribute.
 	 * @return array List of paths to files.
 	 */
 	function getClientFiles($load = LOAD_RELEASE){
@@ -732,7 +732,7 @@ class PluginManager
 	 * @param String $pluginname The name of the plugin (this is used in the pathname)
 	 * @param Array $component The component to read the resourcefiles from
 	 * @param number $load One of LOAD_RELEASE, LOAD_DEBUG, LOAD_SOURCE. This will filter
-	 * the files based on the 'load' attribute. 
+	 * the files based on the 'load' attribute.
 	 * @return array list of paths to the files in this component
 	 */
 	function getResourceFilesForComponent($pluginname, $component, $load)
@@ -749,7 +749,7 @@ class PluginManager
 
 	/**
 	 * getResourceFiles
-	 * 
+	 *
 	 * Returning an array of paths to files that need to be included.
 	 * The paths which are returned start at the root of the webapp.
 	 *
@@ -757,7 +757,7 @@ class PluginManager
 	 * for each component inside each plugin.
 	 *
 	 * @param number $load One of LOAD_RELEASE, LOAD_DEBUG, LOAD_SOURCE. This will filter
-	 * the files based on the 'load' attribute. 
+	 * the files based on the 'load' attribute.
 	 * @return array List of paths to files.
 	 */
 	function getResourceFiles($load = LOAD_RELEASE) {
@@ -788,10 +788,10 @@ class PluginManager
 
 	/**
 	 * getTranslationFilePaths
-	 * 
-	 * Returning an array of paths to to the translations files. This will be 
+	 *
+	 * Returning an array of paths to to the translations files. This will be
 	 * used by the gettext functionality.
-	 * 
+	 *
 	 * @return array List of paths to translations.
 	 */
 	function getTranslationFilePaths(){
@@ -813,9 +813,9 @@ class PluginManager
 
 	/**
 	 * extractPluginDataFromXML
-	 * 
+	 *
 	 * Extracts all the data from the Plugin XML manifest.
-	 * 
+	 *
 	 * @param $xml string XML manifest of plugin
 	 * @return array Data from XML converted into array that the PluginManager can use.
 	 */
@@ -832,12 +832,6 @@ class PluginManager
 		// Parse all XML data
 		$data = $this->xmlParser->getData($xml);
 
-		// debug code will be remove later
-		if(is_a($data, 'PEAR_Error')) {
-			var_dump($data->toString());
-			var_dump($xml);
-		}
-
 		// Parse the <plugin> attributes
 		if (isset($data['attributes'])) {
 			if (isset($data['attributes']['version']) && intval($data['attributes']['version']) !== 2) {
@@ -931,9 +925,9 @@ class PluginManager
 
 	/**
 	 * getConfigFileInfoFromXML
-	 * 
+	 *
 	 * Transform the config files info from a manifest XML to an usable array.
-	 * 
+	 *
 	 * @param $fileData array Piece of manifest XML parsed into array.
 	 * @return array List of config files.
 	 */
@@ -1022,7 +1016,7 @@ class PluginManager
 
 	/**
 	 * getServerFileInfoFromXML
-	 * 
+	 *
 	 * Transform the <serverfile> element array from the manifest into a useable array.
 	 * Each <serverfile> supports the 'load' attribute which needs to be saved into
 	 * the array as well. When this attribute is not provided, the value 'release'
@@ -1032,7 +1026,7 @@ class PluginManager
 	 * the PHP at all times, while the module file will only be loaded on demand. The 'module'
 	 * attribute will only be useful when 'type' is module. If not provided, the 'type' attribute
 	 * will be set to plugin and the 'module' attribute will remain empty.
-	 * 
+	 *
 	 * @param $fileData array Piece of manifest XML which represents all <serverfile> nodes
 	 * @return array List of server files.
 	 */
@@ -1081,18 +1075,18 @@ class PluginManager
 				);
 			}
 		}
- 
+
 		return $files;
 	}
 
 	/**
 	 * getClientFileInfoFromXML
-	 * 
+	 *
 	 * Transform the <clientfile> element array from the manifest into a useable array.
 	 * Each <clientfile> supports the 'load' attribute which needs to be saved into
 	 * the array as well. When this attribute is not provided, the value 'release'
-	 * is assumed. 
-	 * 
+	 * is assumed.
+	 *
 	 * @param $fileData array Piece of manifest XML which represents all <clientfile> nodes
 	 * @return array List of client files.
 	 */
@@ -1134,11 +1128,11 @@ class PluginManager
 
 	/**
 	 * getResourceFileInfoFromXML
-	 * 
+	 *
 	 * Transform the <resourcefile> element array from the manifest into a useable array.
 	 * Each <resourcefile> supports the 'load' attribute which needs to be saved into
 	 * the array as well. When this attribute is not provided, the value 'release'
-	 * is assumed. 
+	 * is assumed.
 	 *
 	 * @param $fileData array Piece of manifest XML which represents all <resourcefile> nodes
 	 * @return array List of resource files.
@@ -1181,7 +1175,7 @@ class PluginManager
 
 	/**
 	 * getTranslationsDirInfoFromXML
-	 * 
+	 *
 	 * Transform the <translationsdir> element array from the manifest into a usable array
 	 * The <translationsdir> doesn't support any attributes.
 	 *
