@@ -13,7 +13,7 @@
  * file for as long as your PHP request is running. However, we want to do multiple PHP requests at
  * once. For this reason, we only use the PHP session system for login information, and use this
  * class for other state information. This means that we can set a message as 'read' at the same time
- * as opening a dialog to view a message. 
+ * as opening a dialog to view a message.
  *
  * Currently, there is one 'state' for each 'subsystem'. The 'subsystem' is simply a tag which is appended
  * to the request URL when the client does an XML request. Each 'subsystem' has its own state file.
@@ -29,7 +29,7 @@ class State {
 	/**
 	 * The file pointer of the state file
 	 */
-	var $fp;
+	var $fp = false;
 
 	/**
 	 * The basedir in which the statefiles are found
@@ -70,12 +70,14 @@ class State {
 	 * The session file is opened and locked so that other processes can not access the state information
 	 */
 	function open() {
-		if (!is_dir($this->basedir)) {
-			mkdir($this->basedir, 0755, true /* recursive */);
+		if($this->fp === false) {
+			if (!is_dir($this->basedir)) {
+				mkdir($this->basedir, 0755, true /* recursive */);
+			}
+			$this->fp = fopen($this->filename, "a+");
+			$this->sessioncache = false;
+			flock($this->fp, LOCK_EX);
 		}
-		$this->fp = fopen($this->filename, "a+");
-		$this->sessioncache = false;
-		flock($this->fp, LOCK_EX);
 	}
 
 	/**
@@ -85,18 +87,21 @@ class State {
 	 * @return string Value of the state value, or null if not found
 	 */
 	function read($name) {
-		// If the file has already been read, we only have to access
-		// our cache to obtain the requeste data.
-		if ($this->sessioncache === false) {
-			$this->contents = file_get_contents($this->filename);
-			$this->sessioncache = unserialize($this->contents);
-		}
+		if($this->fp !== false) {
+			// If the file has already been read, we only have to access
+			// our cache to obtain the requeste data.
+			if ($this->sessioncache === false) {
+				$this->contents = file_get_contents($this->filename);
+				$this->sessioncache = unserialize($this->contents);
+			}
 
-		if (isset($this->sessioncache[$name])) {
-			return $this->sessioncache[$name];
+			if (isset($this->sessioncache[$name])) {
+				return $this->sessioncache[$name];
+			}
 		} else {
-			return false;
+			dump('[STATE ERROR] State file "' . $this->filename . '" isn\'t opened, Please open state file before reading it."');
 		}
+		return false;
 	}
 
 	/**
@@ -109,18 +114,22 @@ class State {
 	 */
 	function write($name, $object, $flush = true)
 	{
-		$contents = "";
+		if($this->fp !== false) {
+			$contents = "";
 
-		// If the file has already been read, then we don't
-		// need to read the entire file again.
-		if ($this->sessioncache === false) {
-			$this->read($name);
-		}
+			// If the file has already been read, then we don't
+			// need to read the entire file again.
+			if ($this->sessioncache === false) {
+				$this->read($name);
+			}
 
-		$this->sessioncache[$name] = $object;
+			$this->sessioncache[$name] = $object;
 
-		if ($flush === true) {
-			$this->flush();
+			if ($flush === true) {
+				$this->flush();
+			}
+		} else {
+			dump('[STATE ERROR] State file "' . $this->filename . '" isn\'t opened, Please open state file before writing on it."');
 		}
 	}
 
@@ -131,14 +140,19 @@ class State {
 	 */
 	function flush()
 	{
-		if ($this->sessioncache) {
-			$contents = serialize($this->sessioncache);
-			if ($contents !== $this->contents) {
-				ftruncate($this->fp, 0);
-				fseek($this->fp, 0);
-				fwrite($this->fp, $contents);
-				$this->contents = $contents;
+		if($this->fp !== false) {
+			if ($this->sessioncache) {
+				$contents = serialize($this->sessioncache);
+
+				if ($contents !== $this->contents) {
+					ftruncate($this->fp, 0);
+					fseek($this->fp, 0);
+					fwrite($this->fp, $contents);
+					$this->contents = $contents;
+				}
 			}
+		} else {
+			dump('[STATE ERROR] State file "' . $this->filename . '" isn\'t opened, Please open state file before writing on it."');
 		}
 	}
 
