@@ -123,11 +123,11 @@ $aDangerousCharsReplacementTable = array(
 function sq_fixIE_idiocy(&$attvalue) {
     global $aDangerousCharsReplacementTable;
 
-    // Shortcut if the value contains only 'normal' characters    
+    // Shortcut if the value contains only 'normal' characters
     if(preg_match("/^[a-zA-Z0-9\";:.,\\s-]*\$/s", $attvalue)) {
         return;
     }
-    
+
     // remove NUL
     $attvalue = str_replace("\0", "", $attvalue);
     // remove comments
@@ -617,6 +617,7 @@ function sq_fixatts($tagname,
             }
         }
 
+        // @FIXME move this to sq_fix_url
         if ($attname == 'href' || $attname == 'src' || $attname == 'background') {
             # If you type \\server\share into Outlook, then it will put
             # file:/// in front of it, making it file:///\\server\share.
@@ -771,25 +772,6 @@ function sq_fixstyle($body, $pos, $message, $id, $mailbox){
 
             case '!':
                 if ($sToken == '<') {
-					// BUG: comments using <!-- is not actualy style comments but its a fallback method to 
-					// not show style data as text content in html block, so its used as html comment
-					// and we shouldn't remove those styles
-
-					/*
-					// possible comment
-					if (isset($body{$i+2}) && substr($body,$i,3) == '!--') {
-						$i = strpos($body,'-->',$i+3);
-
-						if ($i === false) { // no end comment
-							$i = strlen($body);
-						}else{
-							// add length of '-->'
-							$i = $i + 2;
-						}
-					}
-					$sToken = '';
-					}*/
-
 					$content .= $sToken;
 					$sToken = '';
                 } else {
@@ -817,8 +799,7 @@ function sq_fixstyle($body, $pos, $message, $id, $mailbox){
      * and change it to .bodyclass so we can just assign it to a <div>
      */
     $content = preg_replace("|body(\s*\{.*?\})|si", ".bodyclass\\1", $content);
-	// When using the secure images the sec_remove_eng.png needs run throug gettext.
-    $secremoveimg = '../images/' . "sec_remove_eng.png";
+    $secremoveimg = BASE_URL . "/client/resources/images/sec_remove.png";
 
     // first check for 8bit sequences and disallowed control characters
     if (preg_match('/[\16-\37\200-\377]+/',$content)) {
@@ -910,7 +891,7 @@ function sq_body2div($attary, $mailbox, $message, $id){
             switch ($attname){
                 case 'background':
 					/**
-					 * Used to be used to convert cid urls into viewable images. Did not work for 
+					 * Used to be used to convert cid urls into viewable images. Did not work for
 					 * our implementation so removed the functions and calls.
 					 */
                     break;
@@ -995,7 +976,7 @@ function sq_sanitize($body,
         if ($tagname == "style" && $tagtype == 1){
 			/**
 			 * this checks for <p>CONTENT<style></style></p>
-			 * so here when the current tag is <style> and there is some text/content before the start of that tag 
+			 * so here when the current tag is <style> and there is some text/content before the start of that tag
 			 * then we would like to copy that to $trusted string.
 			 */
 			if($free_content != FALSE){
@@ -1004,7 +985,7 @@ function sq_sanitize($body,
 
 			list($style_content, $curpos) =
                 sq_fixstyle($body, $gt+1, $message, $id, $mailbox);
-			
+
             if ($style_content != FALSE){
                 $trusted .= sq_tagprint($tagname, $attary, $tagtype);
                 $trusted .= $style_content;
@@ -1125,17 +1106,12 @@ function sq_sanitize($body,
  */
 function magicHTML($body, $id) {
     $mailbox = '';
-    /**
-     * Don't display attached images in HTML mode.
-     */
-    $attachment_common_show_images = false;
     $tag_list = Array(
             false,
             "object",
             "meta",
             "html",
             "head",
-            "base",
             "link",
             "frame",
             "iframe",
@@ -1158,7 +1134,8 @@ function magicHTML($body, $id) {
             "br",
             "hr",
             "input",
-            "outbind"
+            "outbind",
+            "base"
             );
 
     $force_tag_closing = true;
@@ -1174,7 +1151,9 @@ function magicHTML($body, $id) {
                 )
             );
 
-    $secremoveimg = "../images/" . _("sec_remove_eng.png");
+    // image that will be replaced and shown to user, to indicate we have removed this image because of
+    // security reasons
+    $secremoveimg = BASE_URL . "/client/resources/images/sec_remove.png";
     $bad_attvals = Array(
             "/.*/" =>
             Array(
@@ -1252,25 +1231,12 @@ function magicHTML($body, $id) {
             )
         );
 
-    $view_unsafe_images = true;
-
-    if (!$view_unsafe_images){
-        /**
-         * Remove any references to http/https if view_unsafe_images set
-         * to false.
-         */
-        array_push($bad_attvals{'/.*/'}{'/^src|background/i'}[0],
-                '/^([\'\"])\s*https*:.*([\'\"])/si');
-        array_push($bad_attvals{'/.*/'}{'/^src|background/i'}[1],
-                "\\1$secremoveimg\\1");
-        array_push($bad_attvals{'/.*/'}{'/^style/i'}[0],
-                '/url\([\'\"]?https?:[^\)]*[\'\"]?\)/si');
-        array_push($bad_attvals{'/.*/'}{'/^style/i'}[1],
-                "url(\\1$secremoveimg\\1)");
-    }
-
     $add_attr_to_tag = Array(
             "/^a$/i" =>
+            Array('target'=>'"_blank"',
+                'title'=>'"'._("This external link will open in a new window").'"'
+                ),
+            "/^base$/i" =>
             Array('target'=>'"_blank"',
                 'title'=>'"'._("This external link will open in a new window").'"'
                 )
@@ -1287,8 +1253,16 @@ function magicHTML($body, $id) {
                            $id,
                            $mailbox
                            );
-    if (strpos($trusted,$secremoveimg)){
-        $has_unsafe_images = true;
+
+    // IE has problem with base tags which are part of body, it doesn't consider it valid
+    // to make base href tag valid we should place it only as first statement
+    $matches = array();
+    if(preg_match('/(<base[^>]* href=[^>]*>)/msi', $trusted, $matches) === 1) {
+        // remove base tag from existing position
+        $trusted = preg_replace('/(<base[^>]* href=[^>]*>)/msi', '', $trusted);
+
+        // add it as first line
+        $trusted = $matches[0] . $trusted;
     }
 
     return $trusted;
