@@ -129,7 +129,6 @@
 						$this->getDelegateFolderInfo($store);
 						$data["item"] = $this->getCalendarItems($store, $entryid, $this->startdate, $this->enddate);
 					}
-					$data["restriction"] = $action["restriction"];	// Send restriction back to client
 
 					$this->addActionData("list", $data);
 					$GLOBALS["bus"]->addData($this->getResponseData());
@@ -229,8 +228,7 @@
 			$table = mapi_folder_getcontentstable($folder, MAPI_DEFERRED_ERRORS);
 			$calendaritems = mapi_table_queryallrows($table, $this->properties, $restriction);
 
-			$items = $this->processItems($calendaritems, $store, $entryid, $start, $end);
-			return $items;
+			return $this->processItems($calendaritems, $store, $entryid, $start, $end);
 		}
 		
 		/**
@@ -252,7 +250,7 @@
 				if (isset($calendaritem[$this->properties["recurring"]]) && $calendaritem[$this->properties["recurring"]]) {
 					$recurrence = new Recurrence($store, $calendaritem);
 					$recuritems = $recurrence->getItems($start, $end);
-					
+
 					foreach($recuritems as $recuritem)
 					{
 						$item = Conversion::mapMAPI2XML($this->properties, $recuritem);
