@@ -6,9 +6,6 @@
 	 */
 	class ContactItemModule extends ItemModule
 	{
-
-		var $plaintext;
-
 		/**
 		 * Constructor
 		 * @param int $id unique id.
@@ -18,9 +15,83 @@
 		{
 			$this->properties = $GLOBALS['properties']->getContactProperties();
 			
-			$this->plaintext = true;
-
 			parent::ItemModule($id, $data);
+
+			$this->plaintext = true;
+		}
+
+		/**
+		 * Function which opens an item.
+		 * @param object $store MAPI Message Store Object
+		 * @param string $entryid entryid of the message
+		 * @param array $action the action data, sent by the client
+		 * @return boolean true on success or false on failure 
+		 */
+		function open($store, $entryid, $action)
+		{
+			$data = array();
+
+			if($entryid) {
+				if($store) {
+					$message = $GLOBALS['operations']->openMessage($store, $entryid);
+				} else {
+					// store is not passed so we need to open the message first to get the store resource
+					$message = $GLOBALS['mapisession']->openMessage($entryid);
+
+					$messageStoreInfo = mapi_getprops($message, array(PR_STORE_ENTRYID));
+					$store = $GLOBALS['mapisession']->openMessageStore($messageStoreInfo[PR_STORE_ENTRYID]);
+				}
+			}
+
+			if(empty($message)) {
+				return;
+			}
+
+			// Open embedded message if requested
+			$attachNum = !empty($action['attach_num']) ? $action['attach_num'] : false;
+			if($attachNum) {
+				// get message props of sub message
+				$parentMessage = $message;
+				$message = $GLOBALS['operations']->openMessage($store, $entryid, $attachNum);
+
+				if(empty($message)) {
+					return;
+				}
+
+				// Check if message is distlist then we need to use different set of properties
+				$props = mapi_getprops($message, array(PR_MESSAGE_CLASS));
+
+				if(stripos($props[PR_MESSAGE_CLASS], 'IPM.Distlist') !== false) {
+					// for distlist we need to use different set of properties
+					$this->properties = $GLOBALS['properties']->getDistListProperties();
+				}
+
+				$data['item'] = $GLOBALS['operations']->getEmbeddedMessageProps($store, $message, $this->properties, $parentMessage, $attachNum);
+			} else {
+				// Check if message is distlist then we need to use different set of properties
+				$props = mapi_getprops($message, array(PR_MESSAGE_CLASS));
+
+				if(stripos($props[PR_MESSAGE_CLASS], 'IPM.Distlist') !== false) {
+					// for distlist we need to use different set of properties
+					$this->properties = $GLOBALS['properties']->getDistListProperties();
+				}
+
+				// get message props of the message
+				$data['item'] = $GLOBALS['operations']->getMessageProps($store, $message, $this->properties, $this->plaintext);
+			}
+
+			// Allowing to hook in just before the data sent away to be sent to the client
+			$GLOBALS['PluginManager']->triggerHook('server.module.contactitemmodule.open.after', array(
+				'moduleObject' =>& $this,
+				'store' => $store,
+				'entryid' => $entryid,
+				'action' => $action,
+				'message' =>& $message,
+				'data' =>& $data
+			));
+
+			$this->addActionData('item', $data);
+			$GLOBALS['bus']->addData($this->getResponseData());
 		}
 
 		/**
@@ -52,7 +123,7 @@
 					// DistList
 
 					// for distlist we need to use different set of properties
-					$this->properties = $GLOBALS['properties']->getDistlistProperties();
+					$this->properties = $GLOBALS['properties']->getDistListProperties();
 
 					// do conversion of client data
 					$props = Conversion::mapXML2MAPI($this->properties, $action['props']);
@@ -270,7 +341,8 @@
 			$storeEntryId = bin2hex($rootProps[PR_STORE_ENTRYID]);
 
 			$actionProps = $action['props'];
-			$subject = ($type === 'birthday' ? sprintf(_('%s\'s Birthday'), $actionProps['subject']) : sprintf(_('%s\'s Anniversary'), $actionProps['subject']));
+			$subject = !empty($actionProps['subject']) ? $actionProps['subject'] : _('Untitled');
+			$subject = ($type === 'birthday' ? sprintf(_('%s\'s Birthday'), $subject) : sprintf(_('%s\'s Anniversary'), $subject));
 
 			// UTC time
 			$startDateUTC = $actionProps[$type];
