@@ -37,8 +37,8 @@
 
 						/**
 						 * check content type that is send by browser because content type for
-						 * eml attachments will be message/rfc822, but this content type is used 
-						 * for message-in-message embedded objects, so we have to send it as 
+						 * eml attachments will be message/rfc822, but this content type is used
+						 * for message-in-message embedded objects, so we have to send it as
 						 * application/octet-stream.
 						 */
 						if ($FILE['type'] == 'message/rfc822') {
@@ -101,7 +101,7 @@
 				if($num === false) {
 					// string is passed in attachNum so get it
 					// Parse the filename, strip it from any illegal characters
-					$num = mb_basename(stripslashes(urldecode(sanitizeValue($_POST['attach_num'], '', FILENAME_REGEX))));
+					$num = mb_basename(stripslashes(sanitizePostValue('attach_num', '', FILENAME_REGEX)));
 
 					// Delete the file instance and unregister the file
 					$attachment_state->deleteUploadedAttachmentFile($_REQUEST['dialog_attachments'], $num);
