@@ -1,9 +1,9 @@
 <?php
-    /**
-     * Utility functions
-     *
-     * @package core
-     */
+	/**
+	 * Utility functions
+	 *
+	 * @package core
+	 */
 
 	/**
 	 * Function which reads the data stream. This data is send by the WebClient.
@@ -12,16 +12,16 @@
 	function readData() {
 		$data = "";
 		$putData = fopen("php://input", "r");
-		
-		while($block = fread($putData, 1024)) 
+
+		while($block = fread($putData, 1024))
 		{
 			$data .= $block;
 		}
-		
+
 		fclose($putData);
 		return $data;
-	}	
-	
+	}
+
 	/**
 	 * Function which is called every time the "session_start" method is called.
 	 * It unserializes the objects in the session. This function called by PHP.
@@ -36,7 +36,7 @@
 			case "bus":
 				require_once("core/class.bus.php");
 				break;
-				
+
 			default:
 				$path = BASE_PATH . 'server/notifiers/class.' . $className . '.php';
 				if (is_file($path)) {
@@ -58,24 +58,24 @@
 	 * Function which checks if an array is an associative array.
 	 * @param array $data array which should be verified
 	 * @return boolean true if the given array is an associative array, false if not
-	 */	 	
+	 */
 	function is_assoc_array($data) {
 		return is_array($data) && !empty($data) && !preg_match('/^\d+$/', implode('', array_keys($data)));
 	}
 
 	/**
-	 * Function which is simular to the php function array_merge_recursive, but this 
+	 * Function which is simular to the php function array_merge_recursive, but this
 	 * one overwrites duplicates.
 	 * @param array $array1 array
 	 * @param array $array1 array
-	 * @return array merged array	 	 	 
+	 * @return array merged array
 	 */
 	function array_merge_recursive_overwrite($array1, $array2)
 	{
 		if (!is_array($array1) || !is_array($array2)) {
 			return $array2;
 		}
-		
+
 		foreach ($array2 as $key=>$value) {
 			if (isset($array1[$key])){
 				$array1[$key] = array_merge_recursive_overwrite($array1[$key], $value);
@@ -85,7 +85,7 @@
 		}
 		return $array1;
 	}
-	
+
 	function microtime_float() {
 		list($usec, $sec) = explode(" ", microtime());
 		return ((float)$usec + (float)$sec);
@@ -116,7 +116,7 @@
 		} else if (strpos($upload_max_value, "M")!== false){
 			$upload_max_value = ((int) $upload_max_value) * 1024 * 1024;
 		} else if (strpos($upload_max_value, "G")!== false){
-			$upload_max_value = ((int) $upload_max_value) * 1024 * 1024 * 1024; 
+			$upload_max_value = ((int) $upload_max_value) * 1024 * 1024 * 1024;
 		}
 
 		// calculate post_max_value value to bytes
@@ -125,7 +125,7 @@
 		} else if (strpos($post_max_value, "M")!== false){
 			$post_max_value = ((int) $post_max_value) * 1024 * 1024;
 		} else if (strpos($post_max_value, "G")!== false){
-			$post_max_value = ((int) $post_max_value) * 1024 * 1024 * 1024; 
+			$post_max_value = ((int) $post_max_value) * 1024 * 1024 * 1024;
 		}
 
 		// check which one is larger
@@ -152,7 +152,7 @@
 
 	/**
 	 * cleanTemp
-	 * 
+	 *
 	 * Cleans up the temp directory.
 	 * @param String $directory The path to the temp dir or sessions dir.
 	 * @param Integer $maxLifeTime The maximum allowed age of files in seconds.
@@ -225,9 +225,9 @@
 		$finderfolder = mapi_msgstore_openentry($store, $storeProps[PR_FINDER_ENTRYID]);
 
 		$hierarchytable = mapi_folder_gethierarchytable($finderfolder, MAPI_DEFERRED_ERRORS);
-		mapi_table_restrict($hierarchytable, array(RES_AND, 
+		mapi_table_restrict($hierarchytable, array(RES_AND,
 												array(
-													array(RES_CONTENT, 
+													array(RES_CONTENT,
 														array(
 															FUZZYLEVEL	=> FL_PREFIX,
 															ULPROPTAG	=> PR_DISPLAY_NAME,
@@ -252,9 +252,9 @@
 	}
 
 	function dechex_32($dec){
-		// Because on 64bit systems PHP handles integers as 64bit, 
-		// we need to convert these 64bit integers to 32bit when we 
-		// want the hex value 
+		// Because on 64bit systems PHP handles integers as 64bit,
+		// we need to convert these 64bit integers to 32bit when we
+		// want the hex value
 		$result = unpack("H*",pack("N", $dec));
 		return $result[1];
 	}
@@ -295,7 +295,7 @@
 
 	/**
 	 * getDaysLeftOnTrialPeriod
-	 * Returns the number of days left on the trial of the connected zarafa-server. This number is 
+	 * Returns the number of days left on the trial of the connected zarafa-server. This number is
 	 * based on the remaining seconds left in the trial and rounded up to whole days.
 	 * @return Integer Number of days remaining on trial. Returns 0 when not on a trial license.
 	 */
@@ -316,9 +316,9 @@
 
 	/**
 	 * This function will encode the input string for the header based on the browser that makes the
-	 * HTTP request. MSIE has an issue with unicode filenames. All browsers do not seem to follow 
-	 * the RFC specification. Firefox requires an unencoded string in the HTTP header. MSIE will 
-	 * break on this and requires encoding. 
+	 * HTTP request. MSIE has an issue with unicode filenames. All browsers do not seem to follow
+	 * the RFC specification. Firefox requires an unencoded string in the HTTP header. MSIE will
+	 * break on this and requires encoding.
 	 * @param String $input Unencoded string
 	 * @return String Encoded string
 	 */
@@ -326,12 +326,12 @@
 		if(strpos($_SERVER['HTTP_USER_AGENT'], 'MSIE') === false){
 			return $input;
 		}else{
-			return urlencode($input);
+			return rawurlencode($input);
 		}
 	}
 
 	/**
-	 * This function will return base name of the file from the full path of the file. 
+	 * This function will return base name of the file from the full path of the file.
 	 * PHP's basename() does not properly support streams or filenames beginning with a non-US-ASCII character.
 	 * The default implementation in php for basename is locale aware. so it will truncate umlauts which can not be
 	 * parsed by the current set locale.
@@ -358,14 +358,129 @@
 		return $filename;
 	}
 
+	/**
+	 * Function is used to get data from query string and store it in session
+	 * for use when webapp is completely loaded.
+	 */
+	function storeURLDataToSession()
+	{
+		$data = array();
+		$params = array();
+
+		$urlData = $_SERVER['QUERY_STRING'];
+
+		if(!empty($urlData)) {
+			$urlData = rawurldecode($urlData);
+		} else {
+			return;
+		}
+
+		/*
+		 * mailto link separates mailto address with other data with sign(?), which
+		 * is taken as just regular string by php in $_GET variable, so separate the
+		 * string from '?' and put remaining data in mailtodata variable. It is also
+		 * possible that string contain '&' sign as urlencoded value, so rather
+		 * treating '&' as url query parameter separator, it will be treated as just
+		 * a string. So we need to parse that string manually aswell.
+		 *
+		 * e.g. mailto:someone@zarafa.com?subject=Subject string&body=Body String
+		 */
+		$parts = preg_split('/[?&]/', $urlData, null, PREG_SPLIT_NO_EMPTY);
+
+		if(!empty($parts[1])) {
+			foreach ($parts as $key=>$pair) {
+				$values = explode('=', $pair);
+
+				if(!empty($values[0]) && !empty($values[1])) {
+					$params[strtolower($values[0])] = rawurldecode($values[1]);
+				}
+			}
+		}
+
+		// get data for mailto action
+		if(!empty($params['action']) && $params['action'] === 'mailto') {
+			$mailToData = array();
+
+			// get data for recipients
+			$recipients = array();
+
+			foreach (array('to', 'cc', 'bcc') as $recipType)
+			{
+				if(!isset($params[$recipType])) {
+					continue;
+				}
+
+				$value = $params[$recipType];
+				if($recipType === 'to') {
+					// remove mailto prefix from passed data
+					$value = str_replace('mailto:', '', $value);
+				}
+
+				// TO, CC, BCC field may contain multiple email address with
+				// semicolon(;) or comma(,) as separator.
+				$values = array_map('trim', preg_split('/[;,]/', $value, null, PREG_SPLIT_NO_EMPTY));
+
+				// Convert recipient types to mapi constants
+				$type = MAPI_TO;
+				if($recipType === 'cc') {
+					$type = MAPI_CC;
+				} else if ($recipType === 'bcc') {
+					$type = MAPI_BCC;
+				}
+
+				foreach ($values as $key=>$value) {
+					$value = sanitizeValue($value, '', ALLOWED_EMAIL_CHARS_REGEX);
+
+					if(!empty($value)) {
+						array_push($recipients, array('recipient_type' => $type, 'smtp_address' => $value));
+					}
+				}
+			}
+
+			if(!empty($recipients)) {
+				$mailToData['recipients'] = $recipients;
+			}
+
+			// get data for subject, we can't sanitize subject using regex because it can contain anything
+			if(!empty($params['subject'])) {
+				// we will remove html and php tags from subject as we don't support passing html data in mailto subject
+				// convert encoding to utf-8 to support umlauts
+				$subject = utf8_encode(strip_tags($params['subject']));
+
+				if(!empty($subject)) {
+					$mailToData['subject'] = $subject;
+				}
+			}
+
+			// get data for body, we can't sanitize body using regex because it can contain anything
+			if(!empty($params['body'])) {
+				// we will remove html and php tags from body as we don't support passing html data in mailto body
+				// convert encoding to utf-8 to support umlauts
+				$body = utf8_encode(strip_tags($params['body']));
+
+				if(!empty($body)) {
+					$mailToData['body'] = $body;
+				}
+			}
+
+			// add mailto data to array which will be stored in session
+			$data['mailto'] = $mailToData;
+		}
+
+		if(!empty($data)) {
+			// finally store all data to session
+			$_SESSION['url_action'] = $data;
+		}
+	}
+
 	// Constants for regular expressions which are used in get method to verify the input string
 	define("ID_REGEX", "/^[a-z0-9_]+$/im");
 	define("STRING_REGEX", "/^[a-z0-9_\s()@]+$/im");
 	define("USERNAME_REGEX", "/^[a-z0-9\-\.\'_@]+$/im");
-	define("ALLOWED_EMAIL_CHARS_REGEX", "/^[-a-z0-9_\.@!#\$%&'\*\+/=\?\^_`\{\|\}~]+$/im");
+	define("ALLOWED_EMAIL_CHARS_REGEX", "/^[-a-z0-9_\.@!#\$%&'\*\+\/\=\?\^_`\{\|\}~]+$/im");
 	define("NUMERIC_REGEX", "/^[0-9]+$/im");
 	// Don't allow "\/:*?"<>|" characters in filename.
-	define("FILENAME_REGEX", "/^[^\/\:\*\?\"\<\>\|\\\]+$/im");
+	define("FILENAME_REGEX", "/^[^\/\:\*\?\"\<\>\|]+$/im");
 
 	/**
 	 * Function to sanitize user input values to prevent XSS attacks
@@ -376,14 +491,11 @@
 	 */
 	function sanitizeValue($value, $default = '', $regex = false)
 	{
-		$result = $default;
-
 		$result = addslashes($value);
 		if($regex) {
 			$match = preg_match_all($regex, $result, $matches);
 			if(!$match) {
-				$result = false;
-				$usequote = false;
+				$result = $default;
 			}
 		}
 
@@ -423,4 +535,37 @@
 
 		return $default;
 	}
+
+	/**
+	 * Function will be used to decode smime messages and convert it to normal messages
+	 * @param {MAPIStore} $store user's store
+	 * @param {MAPIMessage} $message smime message
+	 */
+	function parse_smime($store, $message)
+	{
+		$props = mapi_getprops($message, array(PR_MESSAGE_CLASS));
+
+		if(isset($props[PR_MESSAGE_CLASS]) && stripos($props[PR_MESSAGE_CLASS], 'IPM.Note.SMIME.MultipartSigned') !== false) {
+			// this is a signed message. decode it.
+			$atable = mapi_message_getattachmenttable($message);
+
+			$rows = mapi_table_queryallrows($atable, Array(PR_ATTACH_MIME_TAG, PR_ATTACH_NUM));
+			$attnum = false;
+
+			foreach($rows as $row) {
+				if(isset($row[PR_ATTACH_MIME_TAG]) && $row[PR_ATTACH_MIME_TAG] == 'multipart/signed') {
+					$attnum = $row[PR_ATTACH_NUM];
+				}
+			}
+
+			if($attnum !== false) {
+				$att = mapi_message_openattach($message, $attnum);
+				$data = mapi_openproperty($att, PR_ATTACH_DATA_BIN);
+
+				mapi_message_deleteattach($message, $attnum);
+
+				mapi_inetmapi_imtomapi($GLOBALS['mapisession']->getSession(), $store, $GLOBALS['mapisession']->getAddressbook(), $message, $data, Array("parse_smime_signed" => 1));
+			}
+		}
+	}
 ?>
\ No newline at end of file
